Class: Google::Apis::DoubleclickbidmanagerV2::ListQueriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/doubleclickbidmanager_v2/classes.rb,
lib/google/apis/doubleclickbidmanager_v2/representations.rb,
lib/google/apis/doubleclickbidmanager_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListQueriesResponse

Returns a new instance of ListQueriesResponse.



155
156
157
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to queries.list method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


148
149
150
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 148

def next_page_token
  @next_page_token
end

#queriesArray<Google::Apis::DoubleclickbidmanagerV2::Query>

The list of queries. This field will be absent if empty. Corresponds to the JSON property queries



153
154
155
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 153

def queries
  @queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



160
161
162
163
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 160

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @queries = args[:queries] if args.key?(:queries)
end