Class: Google::Apis::DoubleclickbidmanagerV2::ListReportsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/doubleclickbidmanager_v2/classes.rb,
lib/google/apis/doubleclickbidmanager_v2/representations.rb,
lib/google/apis/doubleclickbidmanager_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListReportsResponse

Returns a new instance of ListReportsResponse.



182
183
184
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to queries.reports.list method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


175
176
177
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 175

def next_page_token
  @next_page_token
end

#reportsArray<Google::Apis::DoubleclickbidmanagerV2::Report>

The list of reports. This field will be absent if empty. Corresponds to the JSON property reports



180
181
182
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 180

def reports
  @reports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



187
188
189
190
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 187

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @reports = args[:reports] if args.key?(:reports)
end