Class: Google::Apis::DoubleclickbidmanagerV2::ReportMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DoubleclickbidmanagerV2::ReportMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/doubleclickbidmanager_v2/classes.rb,
lib/google/apis/doubleclickbidmanager_v2/representations.rb,
lib/google/apis/doubleclickbidmanager_v2/representations.rb
Overview
The metadata of a report.
Instance Attribute Summary collapse
-
#google_cloud_storage_path ⇒ String
Output only.
-
#report_data_end_date ⇒ Google::Apis::DoubleclickbidmanagerV2::Date
Represents a whole or partial calendar date, such as a birthday.
-
#report_data_start_date ⇒ Google::Apis::DoubleclickbidmanagerV2::Date
Represents a whole or partial calendar date, such as a birthday.
-
#status ⇒ Google::Apis::DoubleclickbidmanagerV2::ReportStatus
The status of a report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportMetadata
constructor
A new instance of ReportMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportMetadata
Returns a new instance of ReportMetadata.
497 498 499 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_cloud_storage_path ⇒ String
Output only. The location of the generated report file in Google Cloud Storage.
This field will be absent if status.state is not DONE.
Corresponds to the JSON property googleCloudStoragePath
466 467 468 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 466 def google_cloud_storage_path @google_cloud_storage_path end |
#report_data_end_date ⇒ Google::Apis::DoubleclickbidmanagerV2::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property reportDataEndDate
478 479 480 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 478 def report_data_end_date @report_data_end_date end |
#report_data_start_date ⇒ Google::Apis::DoubleclickbidmanagerV2::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property reportDataStartDate
490 491 492 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 490 def report_data_start_date @report_data_start_date end |
#status ⇒ Google::Apis::DoubleclickbidmanagerV2::ReportStatus
The status of a report.
Corresponds to the JSON property status
495 496 497 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 495 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
502 503 504 505 506 507 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 502 def update!(**args) @google_cloud_storage_path = args[:google_cloud_storage_path] if args.key?(:google_cloud_storage_path) @report_data_end_date = args[:report_data_end_date] if args.key?(:report_data_end_date) @report_data_start_date = args[:report_data_start_date] if args.key?(:report_data_start_date) @status = args[:status] if args.key?(:status) end |