Class: Google::Apis::DoubleclickbidmanagerV2::ReportStatus
- Inherits:
-
Object
- Object
- Google::Apis::DoubleclickbidmanagerV2::ReportStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/doubleclickbidmanager_v2/classes.rb,
lib/google/apis/doubleclickbidmanager_v2/representations.rb,
lib/google/apis/doubleclickbidmanager_v2/representations.rb
Overview
The status of a report.
Instance Attribute Summary collapse
-
#finish_time ⇒ String
Output only.
-
#format ⇒ String
The format of the generated report file.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportStatus
constructor
A new instance of ReportStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportStatus
Returns a new instance of ReportStatus.
530 531 532 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#finish_time ⇒ String
Output only. The timestamp of when report generation finished successfully or
in failure. This field will not be set unless state is DONE or FAILED.
Corresponds to the JSON property finishTime
518 519 520 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 518 def finish_time @finish_time end |
#format ⇒ String
The format of the generated report file.
Corresponds to the JSON property format
523 524 525 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 523 def format @format end |
#state ⇒ String
Output only. The state of the report generation.
Corresponds to the JSON property state
528 529 530 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 528 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
535 536 537 538 539 |
# File 'lib/google/apis/doubleclickbidmanager_v2/classes.rb', line 535 def update!(**args) @finish_time = args[:finish_time] if args.key?(:finish_time) @format = args[:format] if args.key?(:format) @state = args[:state] if args.key?(:state) end |